summaryrefslogtreecommitdiffstats
path: root/kompare/libdiff2/kompareprocess.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:49:56 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:49:56 -0600
commite6aaa3624cc6179b82a9bfff1760e742a669064c (patch)
tree3fed4deb0540d34f85dfb53b02bea7519e66cc6f /kompare/libdiff2/kompareprocess.cpp
parent4071ae43ea213cd0f7d5c344c939ebd97d097051 (diff)
downloadtdesdk-e6aaa3624cc6179b82a9bfff1760e742a669064c.tar.gz
tdesdk-e6aaa3624cc6179b82a9bfff1760e742a669064c.zip
Rename KGlobal, KProcess, and KClipboard to avoid conflicts with KDE4
Diffstat (limited to 'kompare/libdiff2/kompareprocess.cpp')
-rw-r--r--kompare/libdiff2/kompareprocess.cpp36
1 files changed, 18 insertions, 18 deletions
diff --git a/kompare/libdiff2/kompareprocess.cpp b/kompare/libdiff2/kompareprocess.cpp
index db165ae5..f66b4e0d 100644
--- a/kompare/libdiff2/kompareprocess.cpp
+++ b/kompare/libdiff2/kompareprocess.cpp
@@ -31,7 +31,7 @@
#include "kompareprocess.h"
KompareProcess::KompareProcess( DiffSettings* diffSettings, enum Kompare::DiffMode mode, TQString source, TQString destination, TQString dir )
- : KProcess(),
+ : TDEProcess(),
m_diffSettings( diffSettings ),
m_mode( mode ),
m_textDecoder( 0 )
@@ -39,14 +39,14 @@ KompareProcess::KompareProcess( DiffSettings* diffSettings, enum Kompare::DiffMo
setUseShell( true );
// connect the stdout and stderr signals
- connect( this, TQT_SIGNAL( receivedStdout( KProcess*, char*, int ) ),
- TQT_SLOT ( slotReceivedStdout( KProcess*, char*, int ) ) );
- connect( this, TQT_SIGNAL( receivedStderr( KProcess*, char*, int ) ),
- TQT_SLOT ( slotReceivedStderr( KProcess*, char*, int ) ) );
+ connect( this, TQT_SIGNAL( receivedStdout( TDEProcess*, char*, int ) ),
+ TQT_SLOT ( slotReceivedStdout( TDEProcess*, char*, int ) ) );
+ connect( this, TQT_SIGNAL( receivedStderr( TDEProcess*, char*, int ) ),
+ TQT_SLOT ( slotReceivedStderr( TDEProcess*, char*, int ) ) );
// connect the signal that indicates that the proces has exited
- connect( this, TQT_SIGNAL( processExited( KProcess* ) ),
- TQT_SLOT ( slotProcessExited( KProcess* ) ) );
+ connect( this, TQT_SIGNAL( processExited( TDEProcess* ) ),
+ TQT_SLOT ( slotProcessExited( TDEProcess* ) ) );
*this << "LANG=C";
@@ -66,8 +66,8 @@ KompareProcess::KompareProcess( DiffSettings* diffSettings, enum Kompare::DiffMo
// Write file names
*this << "--";
- *this << KProcess::quote( constructRelativePath( dir, source ) );
- *this << KProcess::quote( constructRelativePath( dir, destination ) );
+ *this << TDEProcess::quote( constructRelativePath( dir, source ) );
+ *this << TDEProcess::quote( constructRelativePath( dir, destination ) );
}
void KompareProcess::writeDefaultCommandLine()
@@ -86,7 +86,7 @@ void KompareProcess::writeDefaultCommandLine()
void KompareProcess::writeCommandLine()
{
// load the executable into the KProcess
if ( m_diffSettings->m_diffProgram.isEmpty() )
{
kdDebug(8101) << "Using the first diff in the path..." << endl;
@@ -157,7 +157,7 @@ void KompareProcess::writeCommandLine()
if ( m_diffSettings->m_ignoreRegExp && !m_diffSettings->m_ignoreRegExpText.isEmpty() )
{
- *this << "-I " << KProcess::quote( m_diffSettings->m_ignoreRegExpText );
+ *this << "-I " << TDEProcess::quote( m_diffSettings->m_ignoreRegExpText );
}
if ( m_diffSettings->m_showCFunctionChange )
@@ -192,13 +192,13 @@ void KompareProcess::writeCommandLine()
TQStringList::ConstIterator end = m_diffSettings->m_excludeFilePatternList.end();
for ( ; it != end; ++it )
{
- *this << "-x" << KProcess::quote( *it );
+ *this << "-x" << TDEProcess::quote( *it );
}
}
if ( m_diffSettings->m_excludeFilesFile && !m_diffSettings->m_excludeFilesFileURL.isEmpty() )
{
- *this << "-X" << KProcess::quote( m_diffSettings->m_excludeFilesFileURL );
+ *this << "-X" << TDEProcess::quote( m_diffSettings->m_excludeFilesFileURL );
}
}
@@ -214,7 +214,7 @@ void KompareProcess::setEncoding( const TQString& encoding )
}
else
{
- TQTextCodec* textCodec = KGlobal::charsets()->codecForName( encoding.latin1() );
+ TQTextCodec* textCodec = TDEGlobal::charsets()->codecForName( encoding.latin1() );
if ( textCodec )
m_textDecoder = textCodec->makeDecoder();
else
@@ -226,7 +226,7 @@ void KompareProcess::setEncoding( const TQString& encoding )
}
}
-void KompareProcess::slotReceivedStdout( KProcess* /* process */, char* buffer, int length )
+void KompareProcess::slotReceivedStdout( TDEProcess* /* process */, char* buffer, int length )
{
// add all output to m_stdout
if ( m_textDecoder )
@@ -235,7 +235,7 @@ void KompareProcess::slotReceivedStdout( KProcess* /* process */, char* buffer,
kdDebug(8101) << "KompareProcess::slotReceivedStdout : No decoder !!!" << endl;
}
-void KompareProcess::slotReceivedStderr( KProcess* /* process */, char* buffer, int length )
+void KompareProcess::slotReceivedStderr( TDEProcess* /* process */, char* buffer, int length )
{
// add all output to m_stderr
if ( m_textDecoder )
@@ -253,10 +253,10 @@ bool KompareProcess::start()
cmdLine += "\"" + (*it) + "\" ";
kdDebug(8101) << cmdLine << endl;
#endif
- return( KProcess::start( KProcess::NotifyOnExit, KProcess::AllOutput ) );
+ return( TDEProcess::start( TDEProcess::NotifyOnExit, TDEProcess::AllOutput ) );
}
-void KompareProcess::slotProcessExited( KProcess* /* proc */ )
+void KompareProcess::slotProcessExited( TDEProcess* /* proc */ )
{
// exit status of 0: no differences
// 1: some differences
@@ -86,7 +86,7 @@ void KompareProcess::writeDefaultCommandLine()
void KompareProcess::writeCommandLine()
{
- // load the executable into the KProcess
+ // load the executable into the TDEProcess
if ( m_diffSettings->m_diffProgram.isEmpty() )
{